# -*- coding: utf-8 -*-
# Copyright (c) 2009-2017 Michael Howitz
# See also LICENSE.txt

from setuptools import setup, find_packages
import os.path

version = '1.0'


def read(*path):
    """Read a file from a path."""
    return open(os.path.join(*path)).read()


setup(
    name='icemac.truncatetext',
    version=version,
    description=read("README.rst"),
    long_description="\n\n".join([
        read("README.rst"),
        ".. contents::",
        read("icemac", "truncatetext", "README.rst"),
        read("CHANGES.rst"),
        read("HACKING.rst"),
    ]),
    classifiers=[
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Natural Language :: German",
        "Operating System :: OS Independent",
        "Topic :: Utilities",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    keywords='text truncate string intelligent',
    author='Michael Howitz',
    author_email='icemac@gmx.net',
    url='https://bitbucket.org/icemac/icemac.truncatetext',
    license='MIT',
    packages=find_packages(),
    namespace_packages=['icemac'],
    include_package_data=True,
    zip_safe=True,
    install_requires=[
        'setuptools',
    ],
    test_suite="icemac.truncatetext.tests.test_all",
)



# -*- coding: utf-8 -*-

try:
    basestring
except NameError:  # Python 3
    basestring = str


def truncate(text, length, ellipsis='...'):
    """Truncate `text` to `length`, add `ellipsis` if needed."""
    if text is None:
        text = ''
    if not isinstance(text, basestring):
        raise ValueError("%r is no instance of basestring or None" % text)

    # thread other whitespaces as word break
    content = text.replace('\r', ' ').replace('\n', ' ').replace('\t', ' ')
    # make sure to have at least one space for finding spaces later on
    content += ' '

    if len(content) > length:
        # find the next space after max_len chars (do not break inside a word)
        pos = length + content[length:].find(' ')
        if pos != (len(content) - 1):
            # if the found whitespace is not the last one add an ellipsis
            text = text[:pos].strip() + ' ' + ellipsis

    return text
